kimono
======

A minimal python library for the `The Kimono
API <https://www.kimonolabs.com/apidocs>`__ by kimonolabs, inc. Heavily
influenced/plagiarised from the
`pipedrive-api <https://github.com/hiway/pipedrive-api>`__ written by
the awesome `hiway <https://twitter.com/hiway>`__.

**This is a work in progress and is incomplete!**

Usage


.. code:: python

    from kimono import Kimono
    api = Kimono('APIKEY', 'APIID')

Refer to the `wiki <https://github.com/vu3jej/kimono/wiki>`__ for more
detailed documentation!
